CMIP6 Source ID Citation details details
Author: Paul J. Durack
Description: Controlled vocabulary for CMIP6
Keywords: HTML, CSS, JavaScript

# WCRP-CMIP CMIP6_CVs version: 6.2.60.0

#### Experiment IDs | Institution IDs | Source IDs | Source IDs (incl licenses) | Citations by (Source ID, Institution Id, Activity ID) | Citations by (Source ID, Institution Id, Activity ID, Experiment ID) |

Source ID | Institution ID | Activity ID | Data Reference | License | DOI
--- | --- | --- | --- | --- | ---
Source ID | Institution ID | Activity ID | Data Reference | License | DOI
4AOP-v1-5 | IPSL | RFMIP | Boucher, Olivier et al. (2020). IPSL 4AOP-v1-5 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12340 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12340
ACCESS-CM2 | CSIRO-ARCCSS | CMIP | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2281
ACCESS-CM2 | CSIRO-ARCCSS | DAMIP | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14361 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14361
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | Savita, Abhishek et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2282 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2282
ACCESS-CM2 | CSIRO-ARCCSS | RFMIP | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2284 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2284
ACCESS-CM2 | CSIRO-ARCCSS | ScenarioMIP | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2285 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2285
ACCESS-ESM1-5 | CSIRO | C4MIP | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2286 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2286
ACCESS-ESM1-5 | CSIRO | CDRMIP | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2287 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2287
ACCESS-ESM1-5 | CSIRO | CMIP | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2288 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2288
ACCESS-ESM1-5 | CSIRO | DAMIP | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14362 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14362
ACCESS-ESM1-5 | CSIRO | LUMIP | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15741
ACCESS-ESM1-5 | CSIRO | PMIP | Yeung, Nicholas et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13701
ACCESS-ESM1-5 | CSIRO | RFMIP | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2290 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2290
ACCESS-ESM1-5 | CSIRO | ScenarioMIP | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2291 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2291
ACCESS-OM2 | CSIRO-COSIMA | OMIP | Hayashida, Hakase et al. (2021). CSIRO-COSIMA ACCESS-OM2 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14661 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14661
ACCESS-OM2-025 | CSIRO-COSIMA | OMIP | Holmes, Ryan et al. (2021). CSIRO-COSIMA ACCESS-OM2-025 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14663 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14663
ARTS-2-3 | UHH | RFMIP | Brath, Manfred (2019). UHH ARTS2.3 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2001 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2001
AWI-CM-1-1-HR | AWI | HighResMIP | Semmler, Tido et al. (2017). AWI AWI-CM 1.1 HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1202 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1202
AWI-CM-1-1-LR | AWI | HighResMIP | Semmler, Tido et al. (2017). AWI AWI-CM 1.1 LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1209 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1209
AWI-CM-1-1-MR | AWI | CMIP | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.359 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.359
AWI-CM-1-1-MR | AWI | PAMIP | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12021 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12021
AWI-CM-1-1-MR | AWI | ScenarioMIP | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.376 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.376
AWI-ESM-1-1-LR | AWI | CMIP | Danek, Christopher et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9301 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9301
AWI-ESM-1-1-LR | AWI | PMIP | Shi, Xiaoxu et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9302 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9302
AWI-ESM-1-REcoM | AWI | C4MIP | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17721 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17721
AWI-ESM-1-REcoM | AWI | CDRMIP | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17781
AWI-ESM-1-REcoM | AWI | CMIP | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17722 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17722
AWI-ESM-1-REcoM | AWI | ScenarioMIP | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17723 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17723
BCC-CSM2-HR | BCC | HighResMIP | Jie, Weihua et al. (2020). BCC BCC-CSM2HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1722 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1722
BCC-CSM2-MR | BCC | C4MIP | Zhang, Fang et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1723 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1723
BCC-CSM2-MR | BCC | CFMIP | Zhang, Li et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1724 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1724
BCC-CSM2-MR | BCC | CMIP | Xin, Xiaoge et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1725 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1725
BCC-CSM2-MR | BCC | DAMIP | Xin, Xiaoge et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1726 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1726
BCC-CSM2-MR | BCC | DCPP | Fang, Yongjie et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1727 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1727
BCC-CSM2-MR | BCC | GMMIP | Zhang, Jie et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1728 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1728
BCC-CSM2-MR | BCC | LS3MIP | Li, Weiping et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1729 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1729
BCC-CSM2-MR | BCC | LUMIP | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1730 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1730
BCC-CSM2-MR | BCC | ScenarioMIP | Xin, Xiaoge et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1732 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1732
BCC-ESM1 | BCC | AerChemMIP | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1733 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1733
BCC-ESM1 | BCC | CMIP | Zhang, Jie et al. (2018). BCC BCC-ESM1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1734 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1734
CAM-MPAS-HR | PNNL-WACCEM | HighResMIP | Pacific Northwest National Laboratory (PNNL) (2025). PNNL-WACCEM CAM-MPAS-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14021 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14021
CAM-MPAS-LR | PNNL-WACCEM | HighResMIP | Pacific Northwest National Laboratory (PNNL) (2025). PNNL-WACCEM CAM-MPAS-LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14754 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14754
CAMS-CSM1-0 | CAMS | CMIP | Rong, Xinyao (2019). CAMS CAMS_CSM1.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1399 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1399
CAMS-CSM1-0 | CAMS | GMMIP | Chinese Academy of Meteorological Sciences (CAMS) (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11002 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11002
CAMS-CSM1-0 | CAMS | HighResMIP | Rong, Xinyao (2020). CAMS CAMS-CSM1.0 model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11003 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11003
CAMS-CSM1-0 | CAMS | ScenarioMIP | Rong, Xinyao (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11004 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11004
CAS-ESM2-0 | CAS | CDRMIP | Jin, Jiangbo et al. (2023). CAS CAS-ESM2.0 model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17541 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17541
CAS-ESM2-0 | CAS | CMIP | Chai, Zhaoyang (2020). CAS CAS-ESM2.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1944 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1944
CAS-ESM2-0 | CAS | FAFMIP | Chai, Zhaoyang (2020). CAS CAS-ESM2.0 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1948 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1948
CAS-ESM2-0 | CAS | OMIP | Chai, Zhaoyang (2020). CAS CAS-ESM2.0 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1954 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1954
CAS-ESM2-0 | CAS | ScenarioMIP | Chinese Academy of Sciences (CAS) (2020). CAS CAS-ESM2.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1957 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1957
CESM1-1-CAM5-CMIP5 | NCAR | DCPP | Danabasoglu, Gokhan (2019). NCAR CESM1-1-CAM5-CMIP5 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11542 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11542
CESM1-CAM5-SE-HR | NCAR | HighResMIP | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14220 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14220
CESM1-CAM5-SE-LR | NCAR | HighResMIP | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14262
CESM1-WACCM-SC | NCAR | PAMIP | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12281
CESM2 | NCAR | AerChemMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2181 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2181
CESM2 | NCAR | C4MIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2182 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2182
CESM2 | NCAR | CDRMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2183 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2183
CESM2 | NCAR | CFMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2184 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2184
CESM2 | NCAR | CMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2185 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2185
CESM2 | NCAR | DAMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2187 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2187
CESM2 | NCAR | FAFMIP | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14052 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14052
CESM2 | NCAR | GMMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2190 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2190
CESM2 | NCAR | ISMIP6 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ISMIP6. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2193 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2193
CESM2 | NCAR | LS3MIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2194 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2194
CESM2 | NCAR | LUMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2195 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2195
CESM2 | NCAR | OMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2196 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2196
CESM2 | NCAR | PAMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2197 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2197
CESM2 | NCAR | PMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2198 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2198
CESM2 | NCAR | RFMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2199 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2199
CESM2 | NCAR | ScenarioMIP | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2201 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2201
CESM2-FV2 | NCAR | CMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-FV2 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11281
CESM2-FV2 | NCAR | PMIP | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-FV2 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17637 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17637
CESM2-FV2 | NCAR | ScenarioMIP | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-FV2 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17638 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17638
CESM2-WACCM | NCAR | AerChemMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10023 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10023
CESM2-WACCM | NCAR | CMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10024 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10024
CESM2-WACCM | NCAR | GeoMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10025 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10025
CESM2-WACCM | NCAR | RFMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14053 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14053
CESM2-WACCM | NCAR | ScenarioMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10026 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10026
CESM2-WACCM-FV2 | NCAR | CMIP | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11282 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11282
CESM2-WACCM-FV2 | NCAR | PMIP | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17639 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17639
CIESM | THU | CMIP | Huang, Wenyu (2019). THU CIESM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1352 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1352
CIESM | THU | GMMIP | Xue, Wei (2020). THU CIESM model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1354 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1354
CIESM | THU | ScenarioMIP | Huang, Wenyu (2019). THU CIESM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1357 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1357
CMCC-CM2-HR4 | CMCC | CMIP | Scoccimarro, Enrico et al. (2020). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1358 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1358
CMCC-CM2-HR4 | CMCC | HighResMIP | Scoccimarro, Enrico et al. (2017). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1359 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1359
CMCC-CM2-HR4 | CMCC | OMIP | Fogli, Pier Giuseppe et al. (2020). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13161 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13161
CMCC-CM2-SR5 | CMCC | CMIP | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1362 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1362
CMCC-CM2-SR5 | CMCC | DAMIP | Lovato, Tomas; Peano, Daniele (2024). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17942
CMCC-CM2-SR5 | CMCC | DCPP | Nicolì, Dario; Bellucci, Alessio (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1363 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1363
CMCC-CM2-SR5 | CMCC | OMIP | Fogli, Pier Giuseppe et al. (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13162 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13162
CMCC-CM2-SR5 | CMCC | ScenarioMIP | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1365 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1365
CMCC-CM2-VHR4 | CMCC | HighResMIP | Scoccimarro, Enrico et al. (2017). CMCC CMCC-CM2-VHR4 model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1367 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1367
CMCC-ESM2 | CMCC | C4MIP | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13163 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13163
CMCC-ESM2 | CMCC | CMIP | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13164 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13164
CMCC-ESM2 | CMCC | LS3MIP | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13165 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13165
CMCC-ESM2 | CMCC | LUMIP | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13166 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13166
CMCC-ESM2 | CMCC | OMIP | Lovato, Tomas; Butenschön, Momme (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13167 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13167
CMCC-ESM2 | CMCC | ScenarioMIP | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13168 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13168
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1374 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1374
CNRM-CM6-1 | CNRM-CERFACS | CMIP | Voldoire, Aurore (2018). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1375 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1375
CNRM-CM6-1 | CNRM-CERFACS | DAMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1376 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1376
CNRM-CM6-1 | CNRM-CERFACS | DCPP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1377 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1377
CNRM-CM6-1 | CNRM-CERFACS | GMMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1379 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1379
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1925 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1925
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1381 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1381
CNRM-CM6-1 | CNRM-CERFACS | OMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10336 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10336
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9561 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9561
CNRM-CM6-1 | CNRM-CERFACS | PMIP | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1382 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1382
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1383 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1383
CNRM-CM6-1 | CNRM-CERFACS | ScenarioMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1384 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1384
CNRM-CM6-1-HR | CNRM-CERFACS | CMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1385 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1385
CNRM-CM6-1-HR | CNRM-CERFACS | GMMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13921 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13921
CNRM-CM6-1-HR | CNRM-CERFACS | HighResMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1387 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1387
CNRM-CM6-1-HR | CNRM-CERFACS | OMIP | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10337 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10337
CNRM-CM6-1-HR | CNRM-CERFACS | ScenarioMIP | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1388 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1388
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1389 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1389
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1390 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1390
CNRM-ESM2-1 | CNRM-CERFACS | CDRMIP | Seferian, Roland (2021). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9562 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9562
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1391 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1391
CNRM-ESM2-1 | CNRM-CERFACS | DCPP | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17670 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17670
CNRM-ESM2-1 | CNRM-CERFACS | GMMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13922 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13922
CNRM-ESM2-1 | CNRM-CERFACS | GeoMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1392 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1392
CNRM-ESM2-1 | CNRM-CERFACS | LS3MIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9564 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9564
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1393 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1393
CNRM-ESM2-1 | CNRM-CERFACS | OMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1394 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1394
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9565 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9565
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1395 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1395
CanESM5 | CCCma | C4MIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1301 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1301
CanESM5 | CCCma | CDRMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10201 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10201
CanESM5 | CCCma | CFMIP | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1302 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1302
CanESM5 | CCCma | CMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1303 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1303
CanESM5 | CCCma | DAMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1305 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1305
CanESM5 | CCCma | DCPP | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1306 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1306
CanESM5 | CCCma | FAFMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1308 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1308
CanESM5 | CCCma | GMMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1309 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1309
CanESM5 | CCCma | GeoMIP | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1310 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1310
CanESM5 | CCCma | LUMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1313 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1313
CanESM5 | CCCma | OMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1314 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1314
CanESM5 | CCCma | PAMIP | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13942
CanESM5 | CCCma | RFMIP | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1315 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1315
CanESM5 | CCCma | ScenarioMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1317 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1317
CanESM5 | CCCma | VolMIP | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 VolMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10202 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10202
CanESM5-1 | CCCma | CMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17184 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17184
CanESM5-1 | CCCma | ScenarioMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17199 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17199
CanESM5-CanOE | CCCma | C4MIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10203 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10203
CanESM5-CanOE | CCCma | CDRMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10204 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10204
CanESM5-CanOE | CCCma | CMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10205 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10205
CanESM5-CanOE | CCCma | OMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10206 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10206
CanESM5-CanOE | CCCma | ScenarioMIP | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10207 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10207
E3SM-1-0 | E3SM-Project | CMIP | Bader, David C. et al. (2019). E3SM-Project E3SM1.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2294 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2294
E3SM-1-0 | E3SM-Project | DAMIP | Bader, David C. et al. (2022). E3SM-Project E3SM1.0 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16641 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16641
E3SM-1-0 | E3SM-Project | ScenarioMIP | Bader, David C. et al. (2022). E3SM-Project E3SM1.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15102 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15102
E3SM-1-0 | LLNL | CFMIP | Qin, Yi et al. (2021). LLNL E3SM1.0 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15093 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15093
E3SM-1-0 | UCI | PAMIP | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16483 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16483
E3SM-1-0 | UCSB | CMIP | Stevenson, Samantha et al. (2023). UCSB E3SM1.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17062 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17062
E3SM-1-0 | UCSB | ScenarioMIP | Stevenson, Samantha et al. (2023). UCSB E3SM1.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17065 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17065
E3SM-1-1 | E3SM-Project | C4MIP | Bader, David C. et al. (2019). E3SM-Project E3SM1.1 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11441 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11441
E3SM-1-1 | E3SM-Project | CMIP | Bader, David C. et al. (2019). E3SM-Project E3SM1.1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11442 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11442
E3SM-1-1 | E3SM-Project | DAMIP | Bader, David C. et al. (2020). E3SM-Project E3SM1.1 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15781
E3SM-1-1 | E3SM-Project | ScenarioMIP | Bader, David C. et al. (2020). E3SM-Project E3SM1.1 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15103 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15103
E3SM-1-1 | RUBISCO | LS3MIP | Oak Ridge National Laboratory (ORNL) et al. (2020). RUBISCO E3SM1.1 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11676 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11676
E3SM-1-1-ECA | E3SM-Project | C4MIP | Bader, David C. et al. (2020). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11443 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11443
E3SM-1-1-ECA | E3SM-Project | CMIP | Bader, David C. et al. (2019). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11444 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11444
E3SM-1-1-ECA | E3SM-Project | ScenarioMIP | Bader, David C. et al. (2022). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15104
E3SM-2-0 | E3SM-Project | CMIP | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16941 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16941
E3SM-2-0 | E3SM-Project | DAMIP | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17002 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17002
E3SM-2-0 | E3SM-Project | RFMIP | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16942
E3SM-2-0 | E3SM-Project | ScenarioMIP | Bader, David C. et al. (2023). E3SM-Project E3SM2.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16943 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16943
E3SM-2-0-NARRM | E3SM-Project | CMIP | Bader, David C. et al. (2023). E3SM-Project E3SM2.0NARRM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17481 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17481
E3SM-2-1 | E3SM-Project | CMIP | Bader, David C. et al. (2024). E3SM-Project E3SM2.1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17782 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17782
EC-Earth3 | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.181 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.181
EC-Earth3 | EC-Earth-Consortium | DAMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14701
EC-Earth3 | EC-Earth-Consortium | DCPP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.227 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.227
EC-Earth3 | EC-Earth-Consortium | LS3MIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.218 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.218
EC-Earth3 | EC-Earth-Consortium | OMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14702 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14702
EC-Earth3 | EC-Earth-Consortium | PAMIP | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9881 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9881
EC-Earth3 | EC-Earth-Consortium | PMIP | EC-Earth Stockholm group (EC-Earth-S) (2023). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11221 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11221
EC-Earth3 | EC-Earth-Consortium | RFMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.242 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.242
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.251 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.251
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.699 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.699
EC-Earth3-AerChem | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.639 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.639
EC-Earth3-AerChem | EC-Earth-Consortium | RFMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15326 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15326
EC-Earth3-AerChem | EC-Earth-Consortium | ScenarioMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.724 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.724
EC-Earth3-CC | EC-Earth-Consortium | C4MIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.650 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.650
EC-Earth3-CC | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.640 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.640
EC-Earth3-CC | EC-Earth-Consortium | DCPP | EC-Earth BSC group (EC-Earth-BSC) (2022). EC-Earth-Consortium EC-Earth3-CC model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16741
EC-Earth3-CC | EC-Earth-Consortium | ScenarioMIP | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3-CC model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15327 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15327
EC-Earth3-ESM-1 | EC-Earth-Consortium | CMIP | EC-Earth OptimESM partners (EC-Earth-OptimESM) (2024). EC-Earth-Consortium EC-Earth3-ESM-1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17823 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17823
EC-Earth3-HR | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2025). EC-Earth-Consortium EC-Earth3-HR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.201 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.201
EC-Earth3-HR | EC-Earth-Consortium | DCPP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-HR model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.228 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.228
EC-Earth3-HR | EC-Earth-Consortium | ScenarioMIP | EC-Earth Consortium (EC-Earth) (2025). EC-Earth-Consortium EC-Earth3-HR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18122 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18122
EC-Earth3-LR | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.202 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.202
EC-Earth3-LR | EC-Earth-Consortium | PMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.247 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.247
EC-Earth3-Veg | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.642 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.642
EC-Earth3-Veg | EC-Earth-Consortium | LS3MIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.672 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.672
EC-Earth3-Veg | EC-Earth-Consortium | LUMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.692 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.692
EC-Earth3-Veg | EC-Earth-Consortium | PMIP | EC-Earth Stockholm group (EC-Earth-S) (2023). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18101 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18101
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.727 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.727
EC-Earth3-Veg-LR | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.643
EC-Earth3-Veg-LR | EC-Earth-Consortium | PMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.718 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.718
EC-Earth3-Veg-LR | EC-Earth-Consortium | ScenarioMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.728 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.728
EC-Earth3P | EC-Earth-Consortium | HighResMIP | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2322 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2322
EC-Earth3P-HR | EC-Earth-Consortium | HighResMIP | EC-Earth Consortium (EC-Earth) (2018). EC-Earth-Consortium EC-Earth3P-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2323 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2323
EC-Earth3P-VHR | EC-Earth-Consortium | CMIP | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3P-VHR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2326 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2326
EC-Earth3P-VHR | EC-Earth-Consortium | HighResMIP | EC-Earth Consortium (EC-Earth) (2024). EC-Earth-Consortium EC-Earth3P-VHR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2325 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2325
ECMWF-IFS-HR | ECMWF | HighResMIP | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2461 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2461
ECMWF-IFS-LR | ECMWF | HighResMIP | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2463 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2463
ECMWF-IFS-MR | ECMWF | HighResMIP | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-MR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2465 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2465
FGOALS-f3-H | CAS | HighResMIP | Bao, Qing; He, Bian (2019). CAS FGOALS-f3-H model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2041
FGOALS-f3-H | CAS | OMIP | Lin, Pengfei (2020). CAS FGOALS-f3-H model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13261 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13261
FGOALS-f3-L | CAS | CMIP | YU, Yongqiang (2018). CAS FGOALS-f3-L model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1782 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1782
FGOALS-f3-L | CAS | DCPP | Hu, Shuai et al. (2022). CAS FGOALS-f3-L model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2042 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2042
FGOALS-f3-L | CAS | GMMIP | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2043 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2043
FGOALS-f3-L | CAS | HighResMIP | Bao, Qing; He, Bian (2019). CAS FGOALS-f3-L model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12001 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12001
FGOALS-f3-L | CAS | OMIP | Lin, Pengfei (2019). CAS FGOALS-f3-L model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2044 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2044
FGOALS-f3-L | CAS | PAMIP | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11497 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11497
FGOALS-f3-L | CAS | PMIP | Zheng, Weipeng; He, Bian (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12002 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12002
FGOALS-f3-L | CAS | ScenarioMIP | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2046 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2046
FGOALS-g3 | CAS | CMIP | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1783 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1783
FGOALS-g3 | CAS | DAMIP | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2048 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2048
FGOALS-g3 | CAS | FAFMIP | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2050 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2050
FGOALS-g3 | CAS | GMMIP | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2051 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2051
FGOALS-g3 | CAS | LS3MIP | Jia, Binghao et al. (2020). CAS FGOALS-g3 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2052 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2052
FGOALS-g3 | CAS | PMIP | Zheng, Weipeng; Dong, Li (2019). CAS FGOALS-g3 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2054 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2054
FGOALS-g3 | CAS | ScenarioMIP | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2056 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2056
FIO-ESM-2-0 | FIO-QLNM | CMIP | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9047 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9047
FIO-ESM-2-0 | FIO-QLNM | GMMIP | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9049 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9049
FIO-ESM-2-0 | FIO-QLNM | OMIP | Song, Zhenya et al. (2020). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9050 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9050
FIO-ESM-2-0 | FIO-QLNM | ScenarioMIP | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9051 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9051
GFDL-AM4 | NOAA-GFDL | CMIP | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-AM4 model output. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1401 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1401
GFDL-CM4 | NOAA-GFDL | CFMIP | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1641 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1641
GFDL-CM4 | NOAA-GFDL | CMIP | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1402 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1402
GFDL-CM4 | NOAA-GFDL | DAMIP | Ploshay, Jeffrey et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11383 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11383
GFDL-CM4 | NOAA-GFDL | GMMIP | Xiang, Baoqiang et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1642 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1642
GFDL-CM4 | NOAA-GFDL | OMIP | Adcroft, Alistair et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1403 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1403
GFDL-CM4 | NOAA-GFDL | RFMIP | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1643
GFDL-CM4 | NOAA-GFDL | ScenarioMIP | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9242 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9242
GFDL-CM4C192 | NOAA-GFDL | HighResMIP | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-CM4C192 model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2262
GFDL-ESM2M | NOAA-GFDL | FAFMIP | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1645 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1645
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1404 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1404
GFDL-ESM4 | NOAA-GFDL | C4MIP | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1405 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1405
GFDL-ESM4 | NOAA-GFDL | CDRMIP | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1981 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1981
GFDL-ESM4 | NOAA-GFDL | CMIP | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1407 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1407
GFDL-ESM4 | NOAA-GFDL | DAMIP | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1408 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1408
GFDL-ESM4 | NOAA-GFDL | LUMIP | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1411 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1411
GFDL-ESM4 | NOAA-GFDL | RFMIP | Paynter, David J et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11961 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11961
GFDL-ESM4 | NOAA-GFDL | ScenarioMIP | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1414 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1414
GFDL-GRTCODE | NOAA-GFDL | RFMIP | Paynter, David J et al. (2018). NOAA-GFDL GFDL-GRTCODE model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10404 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10404
GFDL-OM4p5B | NOAA-GFDL | OMIP | Zadeh, Niki T. et al. (2018). NOAA-GFDL GFDL-OM4p5B model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2264 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2264
GFDL-RFM-DISORT | NOAA-GFDL | RFMIP | Paynter, David J et al. (2018). NOAA-GFDL GFDL-RFM-DISORT model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10406 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10406
GISS-E2-1-G | NASA-GISS | AerChemMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2059 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2059
GISS-E2-1-G | NASA-GISS | C4MIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2060 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2060
GISS-E2-1-G | NASA-GISS | CFMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2061 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2061
GISS-E2-1-G | NASA-GISS | CMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1400 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.1400
GISS-E2-1-G | NASA-GISS | DAMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2062 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2062
GISS-E2-1-G | NASA-GISS | ISMIP6 | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ISMIP6. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2066 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2066
GISS-E2-1-G | NASA-GISS | LS3MIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2067 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2067
GISS-E2-1-G | NASA-GISS | LUMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2068 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2068
GISS-E2-1-G | NASA-GISS | PMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2071 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2071
GISS-E2-1-G | NASA-GISS | RFMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2072 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2072
GISS-E2-1-G | NASA-GISS | ScenarioMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2074 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2074
GISS-E2-1-G | NASA-GISS | VolMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 VolMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2076 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2076
GISS-E2-1-G-CC | NASA-GISS | C4MIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11656 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11656
GISS-E2-1-G-CC | NASA-GISS | CMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11657 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11657
GISS-E2-1-G-CC | NASA-GISS | ScenarioMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17581 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17581
GISS-E2-1-H | NASA-GISS | AerChemMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18060 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.18060
GISS-E2-1-H | NASA-GISS | CFMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13941 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.13941
GISS-E2-1-H | NASA-GISS | CMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1421 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.1421
GISS-E2-1-H | NASA-GISS | ScenarioMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2080 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2080
GISS-E2-2-G | NASA-GISS | CFMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11659 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11659
GISS-E2-2-G | NASA-GISS | CMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2081 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2081
GISS-E2-2-G | NASA-GISS | DAMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11660 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11660
GISS-E2-2-G | NASA-GISS | ScenarioMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11671 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11671
GISS-E2-2-H | NASA-GISS | CFMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17582 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17582
GISS-E2-2-H | NASA-GISS | CMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15861 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.15861
GISS-E3-G | NASA-GISS | CMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E3-G model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2087 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2087
GISS-E3-G | NASA-GISS | RFMIP | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E3-G model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2098 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.2098
HadGEM3-GC31-HH | MOHC | HighResMIP | Roberts, Malcolm (2018). MOHC HadGEM3-GC31-HH model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.445 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.445
HadGEM3-GC31-HH | NERC | HighResMIP | Coward, Andrew; Roberts, Malcolm (2018). NERC HadGEM3-GC31-HH model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1822 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1822
HadGEM3-GC31-HM | MOHC | HighResMIP | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.446 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.446
HadGEM3-GC31-HM | NERC | HighResMIP | Schiemann, Reinhard et al. (2019). NERC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1824 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1824
HadGEM3-GC31-LL | MOHC | CFMIP | Webb, Mark (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.435 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.435
HadGEM3-GC31-LL | MOHC | CMIP | Ridley, Jeff et al. (2018). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.419 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.419
HadGEM3-GC31-LL | MOHC | DAMIP | Jones, Gareth (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.471 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.471
HadGEM3-GC31-LL | MOHC | HighResMIP | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1901
HadGEM3-GC31-LL | MOHC | LS3MIP | Wiltshire, Andy et al. (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14460 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14460
HadGEM3-GC31-LL | MOHC | LUMIP | Wiltshire, Andy et al. (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14461 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14461
HadGEM3-GC31-LL | MOHC | RFMIP | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.475 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.475
HadGEM3-GC31-LL | MOHC | ScenarioMIP | Good, Peter (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10845 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10845
HadGEM3-GC31-LL | NERC | FAFMIP | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12065 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12065
HadGEM3-GC31-LL | NERC | PMIP | Williams, Charlie et al. (2020). NERC HadGEM3-GC31-LL model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12067 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12067
HadGEM3-GC31-LM | MOHC | HighResMIP | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-LM model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1321 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1321
HadGEM3-GC31-MH | MOHC | HighResMIP | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MH model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1762 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1762
HadGEM3-GC31-MM | MOHC | CMIP | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.420 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.420
HadGEM3-GC31-MM | MOHC | DCPP | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.456 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.456
HadGEM3-GC31-MM | MOHC | HighResMIP | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1902 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1902
HadGEM3-GC31-MM | MOHC | PAMIP | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14627 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14627
HadGEM3-GC31-MM | MOHC | ScenarioMIP | Jackson, Laura (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10846 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10846
HiRAM-SIT-HR | AS-RCEC | HighResMIP | Tu, Chia-Ying (2020). AS-RCEC HiRAM-SIT-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13301 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13301
HiRAM-SIT-LR | AS-RCEC | HighResMIP | Tu, Chia-Ying (2020). AS-RCEC HiRAM-SIT-LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13303 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13303
ICON-ESM-LR | MPI-M | CMIP | Lorenz, Stephan et al. (2021). MPI-M ICON-ESM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.743 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.743
IITM-ESM | CCCR-IITM | CMIP | Panickal, Swapna et al. (2019). CCCR-IITM IITM-ESM model output data prepared for CMIP6 CMIP/DECK. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.44 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.44
IITM-ESM | CCCR-IITM | GMMIP | Modi, Aditi et al. (2019). CCCR-IITM IITM-ESM model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.825 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.825
IITM-ESM | CCCR-IITM | ScenarioMIP | Panickal, Swapna et al. (2020). CCCR-IITM IITM-ESM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14741
INM-CM4-8 | INM | CMIP | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1422 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1422
INM-CM4-8 | INM | PMIP | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2295 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2295
INM-CM4-8 | INM | ScenarioMIP | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12321 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12321
INM-CM5-0 | INM | CMIP | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1423 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1423
INM-CM5-0 | INM | ScenarioMIP | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12322 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12322
INM-CM5-H | INM | HighResMIP | Volodin, Evgeny et al. (2019). INM INM-CM5-H model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14041
IPSL-CM5A2-INCA | IPSL | AerChemMIP | Boucher, Olivier et al. (2021). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13641 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13641
IPSL-CM5A2-INCA | IPSL | CMIP | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13642 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13642
IPSL-CM5A2-INCA | IPSL | LUMIP | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15666 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15666
IPSL-CM5A2-INCA | IPSL | ScenarioMIP | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15667 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15667
IPSL-CM6A-ATM-HR | IPSL | HighResMIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-ATM-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2361 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2361
IPSL-CM6A-ATM-ICO-HR | IPSL | HighResMIP | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16361 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16361
IPSL-CM6A-ATM-ICO-LR | IPSL | HighResMIP | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16363 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16363
IPSL-CM6A-ATM-ICO-MR | IPSL | HighResMIP | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-MR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16365 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16365
IPSL-CM6A-ATM-ICO-VHR | IPSL | HighResMIP | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-VHR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16367 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16367
IPSL-CM6A-ATM-LR-REPROBUS | IPSL | AerChemMIP | Boucher, Olivier et al. (2024). IPSL IPSL-CM6A-ATM-LR-REPROBUS model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16581 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16581
IPSL-CM6A-LR | IPSL | AerChemMIP | Boucher, Olivier et al. (2021). IPSL IPSL-CM6A-LR model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17797 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17797
IPSL-CM6A-LR | IPSL | C4MIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1521 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1521
IPSL-CM6A-LR | IPSL | CFMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1522 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1522
IPSL-CM6A-LR | IPSL | CMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1534 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1534
IPSL-CM6A-LR | IPSL | DAMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13801 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13801
IPSL-CM6A-LR | IPSL | DCPP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1523 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1523
IPSL-CM6A-LR | IPSL | GMMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1525 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1525
IPSL-CM6A-LR | IPSL | GeoMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1526 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1526
IPSL-CM6A-LR | IPSL | HighResMIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13803 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13803
IPSL-CM6A-LR | IPSL | LS3MIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1527 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1527
IPSL-CM6A-LR | IPSL | LUMIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1528 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1528
IPSL-CM6A-LR | IPSL | OMIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1529 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1529
IPSL-CM6A-LR | IPSL | PAMIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13802 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13802
IPSL-CM6A-LR | IPSL | PMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1530
IPSL-CM6A-LR | IPSL | RFMIP | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1531 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1531
IPSL-CM6A-LR | IPSL | ScenarioMIP | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1532 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1532
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13581 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13581
IPSL-CM6A-LR-INCA | IPSL | CMIP | Boucher, Olivier et al. (2021). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13582 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13582
IPSL-CM6A-LR-INCA | IPSL | RFMIP | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14583 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14583
IPSL-CM6A-MR1 | IPSL | CMIP | Boucher, Olivier et al. (2023). IPSL IPSL-CM6A-MR1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15922 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15922
KACE-1-0-G | NIMS-KMA | CMIP | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2241 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2241
KACE-1-0-G | NIMS-KMA | ScenarioMIP | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2242 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2242
KIOST-ESM | KIOST | CMIP | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1922 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1922
KIOST-ESM | KIOST | ScenarioMIP | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11241 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11241
LBLRTM-12-8 | AER | RFMIP | Mlawer, Eli; Pernak, Richard (2019). AER LBLRTM model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2003 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2003
MCM-UA-1-0 | UA | CMIP | Stouffer, Ronald (2019). U of Arizona MCM-UA-1-0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2421 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2421
MCM-UA-1-0 | UA | ScenarioMIP | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13816 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13816
MIROC-ES2H | MIROC | CMIP | Watanabe, Shingo et al. (2021). MIROC MIROC-ES2H model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.901
MIROC-ES2H | MIROC | GeoMIP | Watanabe, Shingo et al. (2021). MIROC MIROC-ES2H model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.907 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.907
MIROC-ES2H | MIROC | ScenarioMIP | Watanabe, Shingo et al. (2023). MIROC MIROC-ES2H model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15638 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15638
MIROC-ES2H-NB | MIROC | AerChemMIP | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13305 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13305
MIROC-ES2L | MIROC | C4MIP | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.906 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.906
MIROC-ES2L | MIROC | CDRMIP | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2161 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2161
MIROC-ES2L | MIROC | CMIP | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.902 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.902
MIROC-ES2L | MIROC | DAMIP | Ohgaito, Rumi et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15241 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15241
MIROC-ES2L | MIROC | LUMIP | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.922 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.922
MIROC-ES2L | MIROC | OMIP | Watanabe, Michio et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.934 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.934
MIROC-ES2L | MIROC | PMIP | Ohgaito, Rumi et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.932 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.932
MIROC-ES2L | MIROC | ScenarioMIP | Tachiiri, Kaoru et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.936 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.936
MIROC-ES2L | MIROC | VolMIP | Abe, Manabu et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 VolMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.918 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.918
MIROC6 | MIROC | AerChemMIP | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9121 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9121
MIROC6 | MIROC | CFMIP | Ogura, Tomoo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.885 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.885
MIROC6 | MIROC | CMIP | Tatebe, Hiroaki; Watanabe, Masahiro (2018). MIROC MIROC6 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.881 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.881
MIROC6 | MIROC | DAMIP | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.894 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.894
MIROC6 | MIROC | DCPP | Mochizuki, Takashi et al. (2019). MIROC MIROC6 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.890 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.890
MIROC6 | MIROC | FAFMIP | Suzuki, Tatsuo (2019). MIROC MIROC6 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.892 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.892
MIROC6 | MIROC | GMMIP | Watanabe, Masahiro; Tatebe, Hiroaki (2019). MIROC MIROC6 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.886 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.886
MIROC6 | MIROC | LS3MIP | Onuma, Yukihiko; Kim, Hyungjun (2020). MIROC MIROC6 model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.887 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.887
MIROC6 | MIROC | OMIP | Komuro, Yoshiki (2019). MIROC MIROC6 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.897 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.897
MIROC6 | MIROC | PAMIP | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2162 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2162
MIROC6 | MIROC | RFMIP | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.895 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.895
MIROC6 | MIROC | ScenarioMIP | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.898 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.898
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1621 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1621
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | CMIP | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1622 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1622
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | RFMIP | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14724 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14724
MPI-ESM1-2-HR | DKRZ | ScenarioMIP | Schupfner, Martin et al. (2019). DKRZ MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2450 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2450
MPI-ESM1-2-HR | DWD | ScenarioMIP | Steger, Christian et al. (2019). DWD MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1869 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1869
MPI-ESM1-2-HR | MPI-M | CMIP | Jungclaus, Johann et al. (2019). MPI-M MPIESM1.2-HR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.741
MPI-ESM1-2-HR | MPI-M | DCPP | Pohlmann, Holger et al. (2019). MPI-M MPIESM1.2-HR model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.768 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.768
MPI-ESM1-2-HR | MPI-M | FAFMIP | Haak, Helmuth et al. (2019). MPI-M MPIESM1.2-HR model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.774 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.774
MPI-ESM1-2-HR | MPI-M | GeoMIP | Niemeier, Ulrike et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15294 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15294
MPI-ESM1-2-HR | MPI-M | HighResMIP | von Storch, Jin-Song et al. (2017). MPI-M MPIESM1.2-HR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.762 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.762
MPI-ESM1-2-HR | MPI-M | VolMIP | Timmreck, Claudia et al. (2019). MPI-M MPIESM1.2-HR model output prepared for CMIP6 VolMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.765 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.765
MPI-ESM1-2-LR | DKRZ | ScenarioMIP | Schupfner, Martin et al. (2021). DKRZ MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15349 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15349
MPI-ESM1-2-LR | DWD | DCPP | Steger, Christian et al. (2022). DWD MPI-ESM1.2-LR model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16046 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16046
MPI-ESM1-2-LR | MPI-M | C4MIP | Brovkin, Victor et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.748
MPI-ESM1-2-LR | MPI-M | CDRMIP | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2142 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2142
MPI-ESM1-2-LR | MPI-M | CMIP | Wieners, Karl-Hermann et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.742 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.742
MPI-ESM1-2-LR | MPI-M | DAMIP | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15016 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15016
MPI-ESM1-2-LR | MPI-M | FAFMIP | Haak, Helmuth et al. (2021). MPI-M MPIESM1.2-LR model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.775 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.775
MPI-ESM1-2-LR | MPI-M | GeoMIP | Niemeier, Ulrike et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.751 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.751
MPI-ESM1-2-LR | MPI-M | LS3MIP | Stacke, Tobias et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.760 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.760
MPI-ESM1-2-LR | MPI-M | LUMIP | Pongratz, Julia et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.772 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.772
MPI-ESM1-2-LR | MPI-M | PMIP | Jungclaus, Johann et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.787 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.787
MPI-ESM1-2-LR | MPI-M | RFMIP | Fiedler, Stephanie et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.784 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.784
MPI-ESM1-2-LR | MPI-M | ScenarioMIP | Wieners, Karl-Hermann et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.793 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.793
MPI-ESM1-2-LR | MPI-M | VolMIP | Timmreck, Claudia et al. (2019). MPI-M MPIESM1.2-LR model output prepared for CMIP6 VolMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.766 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.766
MPI-ESM1-2-XR | MPI-M | HighResMIP | von Storch, Jin-Song et al. (2017). MPI-M MPI-ESM1.2-XR model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10290 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10290
MRI-AGCM3-2-H | MRI | HighResMIP | Mizuta, Ryo et al. (2019). MRI MRI-AGCM3-2-H model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10942
MRI-AGCM3-2-S | MRI | HighResMIP | Mizuta, Ryo et al. (2019). MRI MRI-AGCM3-2-S model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1625 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1625
MRI-ESM2-0 | MRI | AerChemMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.633 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.633
MRI-ESM2-0 | MRI | C4MIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.623 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.623
MRI-ESM2-0 | MRI | CFMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.625 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.625
MRI-ESM2-0 | MRI | CMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.621 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.621
MRI-ESM2-0 | MRI | DAMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.634 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.634
MRI-ESM2-0 | MRI | DCPP | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.630 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.630
MRI-ESM2-0 | MRI | FAFMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.632 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.632
MRI-ESM2-0 | MRI | GMMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.626 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.626
MRI-ESM2-0 | MRI | OMIP | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.637 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.637
MRI-ESM2-0 | MRI | PMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.636 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.636
MRI-ESM2-0 | MRI | RFMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.635 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.635
MRI-ESM2-0 | MRI | ScenarioMIP | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.638 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.638
NESM3 | NUIST | CMIP | Cao, Jian; Wang, Bin (2019). NUIST NESMv3 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2021 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2021
NESM3 | NUIST | PMIP | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2026 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2026
NESM3 | NUIST | ScenarioMIP | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2027 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2027
NICAM16-7S | MIROC | HighResMIP | Kodama, Chihiro et al. (2019). MIROC NICAM16-7S model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1033 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1033
NICAM16-8S | MIROC | HighResMIP | Kodama, Chihiro et al. (2019). MIROC NICAM16-8S model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1034 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1034
NICAM16-9S | MIROC | HighResMIP | Kodama, Chihiro et al. (2019). MIROC NICAM16-9S model output prepared for CMIP6 HighResMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1036 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1036
NorCPM1 | NCC | CMIP | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10843 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10843
NorCPM1 | NCC | DCPP | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 DCPP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10844 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10844
NorESM1-F | NCC | CMIP | Guo, Chuncheng et al. (2019). NCC NorESM1-F model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11543 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11543
NorESM1-F | NCC | PMIP | Guo, Chuncheng et al. (2019). NCC NorESM1-F model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11544 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11544
NorESM2-LM | NCC | AerChemMIP | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.574 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.574
NorESM2-LM | NCC | C4MIP | Schwinger, Jörg et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13721 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13721
NorESM2-LM | NCC | CDRMIP | Tjiputra, Jerry et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13722 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13722
NorESM2-LM | NCC | CFMIP | Oliviè, Dirk Jan Leo et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.526 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.526
NorESM2-LM | NCC | CMIP | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.502 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.502
NorESM2-LM | NCC | DAMIP | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.580 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.580
NorESM2-LM | NCC | GeoMIP | Oliviè, Dirk Jan Leo et al. (2025). NCC NorESM2-LM model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18121 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18121
NorESM2-LM | NCC | LUMIP | Cai, Lei et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.562 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.562
NorESM2-LM | NCC | OMIP | Bentsen, Mats et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.598 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.598
NorESM2-LM | NCC | PAMIP | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13723 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13723
NorESM2-LM | NCC | PMIP | Zhang, Zhongshi et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.592 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.592
NorESM2-LM | NCC | RFMIP | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.586 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.586
NorESM2-LM | NCC | ScenarioMIP | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.604 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.604
NorESM2-MM | NCC | CMIP | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.506 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.506
NorESM2-MM | NCC | RFMIP | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-MM model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.590 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.590
NorESM2-MM | NCC | ScenarioMIP | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.608 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.608
RRTMG-LW-4-91 | AER | RFMIP | Mlawer, Eli; Pernak, Richard (2020). AER RRTMG-LW4.91 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9961 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9961
RRTMG-SW-4-02 | AER | RFMIP | Mlawer, Eli; Pernak, Richard (2020). AER RRTMG-SW4.02 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9963 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9963
RTE-RRTMGP-181204 | RTE-RRTMGP-Consortium | RFMIP | Pincus, Robert (2019). RTE-RRTMGP-Consortium RTE+RRTMGP (2018-12-04full-resolution) model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10124 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10124
SAM0-UNICON | SNU | CMIP | Park, Sungsu; Shin, Jihoon (2019). SNU SAM0-UNICON model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1489 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1489
TaiESM1 | AS-RCEC | AerChemMIP | Tsai, I-Chun et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9682 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9682
TaiESM1 | AS-RCEC | CFMIP | Shiu, Chein-Jung et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9683 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9683
TaiESM1 | AS-RCEC | CMIP | Lee, Wei-Liang; Liang, Hsin-Chien (2019). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9684 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9684
TaiESM1 | AS-RCEC | GMMIP | Wang, Yi-Chi et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 GMMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9685 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9685
TaiESM1 | AS-RCEC | PAMIP | Hong, Hao-Jhe et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 PAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15214 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15214
TaiESM1 | AS-RCEC | RFMIP | Lee, Wei-Liang; Liang, Hsin-Chien (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17701
TaiESM1 | AS-RCEC | ScenarioMIP | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9688 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9688
TaiESM1-TIMCOM | NTU | OMIP | Tseng, Yu-Heng et al. (2020). NTU TaiESM1-TIMCOM model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14323 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14323
TaiESM1-TIMCOM2 | NTU | OMIP | Tseng, Yu-Heng et al. (2021). NTU TaiESM1-TIMCOM2 model output prepared for CMIP6 OMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16323 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16323
UKESM1-0-LL | MOHC | AerChemMIP | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1561 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1561
UKESM1-0-LL | MOHC | C4MIP | Liddicoat, Spencer et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1562 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1562
UKESM1-0-LL | MOHC | CDRMIP | Jones, Chris et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12181 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12181
UKESM1-0-LL | MOHC | CMIP | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1569 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1569
UKESM1-0-LL | MOHC | DAMIP | Rumbold, Steve et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 DAMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14830 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14830
UKESM1-0-LL | MOHC | GeoMIP | Jones, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 GeoMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1563 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1563
UKESM1-0-LL | MOHC | LS3MIP | Wiltshire, Andy et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LS3MIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14462 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14462
UKESM1-0-LL | MOHC | LUMIP | Wiltshire, Andy et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1564 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1564
UKESM1-0-LL | MOHC | RFMIP | O'Connor, Fiona et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 RFMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11061 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11061
UKESM1-0-LL | MOHC | ScenarioMIP | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1567 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1567
UKESM1-0-LL | NERC | AerChemMIP | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.405 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.405
UKESM1-0-LL | NERC | VolMIP | Natural Environment Research Council (NERC) (2023). NERC UKESM1.0-LL model output prepared for CMIP6 VolMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.397 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.397
UKESM1-0-LL | NIMS-KMA | AerChemMIP | Shim, Sungbo et al. (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2243 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2243
UKESM1-0-LL | NIMS-KMA | CMIP | Shim, Sungbo et al. (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2245 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2245
UKESM1-0-LL | NIMS-KMA | ScenarioMIP | Shim, Sungbo et al. (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2250 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2250
UKESM1-0-LL | NIWA | AerChemMIP | Dalvi, Mohit et al. (2019). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.1741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.1741
UKESM1-1-LL | MOHC | CMIP | Mulcahy, Jane et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 CMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16781
UKESM1-1-LL | MOHC | ScenarioMIP | Walton, Jeremy et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 ScenarioMIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16782 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16782
UKESM1-ice-LL | NERC | ISMIP6 | Smith, Robin et al. (2022). NERC UKESM1.ice-LL model output prepared for CMIP6 ISMIP6. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13423 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13423